@@ -26,7 +26,7 @@
  *  USA.
  */
 
-#include <rfb/rfb.h>
+#include "rfb/rfb.h"
 
 void
 rfbAuthInitScreen(rfbScreenInfoPtr rfbScreen)
@@ -75,7 +75,7 @@ rfbAuthTLSHandshake(rfbClientPtr cl)
     gnutls_credentials_set(cl->tlsSession,
 			   GNUTLS_CRD_ANON,
 			   cl->screen->anonCredentials);
-    gnutls_transport_set_ptr(cl->tlsSession, (gnutls_transport_ptr) cl->sock);
+    gnutls_transport_set_ptr(cl->tlsSession, (gnutls_transport_ptr_t) cl->sock);
 
     err = gnutls_handshake(cl->tlsSession);
     if (err != GNUTLS_E_SUCCESS && !gnutls_error_is_fatal(err)) {
@@ -151,7 +151,10 @@ rfbAuthNewClient3_7(rfbClientPtr cl)
 static void
 rfbAuthNewClient3_3(rfbClientPtr cl)
 {
-    char buf[4 + CHALLENGESIZE];
+    union {
+        uint32_t authType;
+        char buf[4 + CHALLENGESIZE];
+    } auth;
     int len, i;
 
     for (i = 0; i < cl->screen->nSecurityTypes; i++)
@@ -166,14 +169,14 @@ rfbAuthNewClient3_3(rfbClientPtr cl)
 
     switch (cl->screen->securityTypes [i]) {
     case rfbVncAuth:
-        *(uint32_t *)buf = Swap32IfLE(rfbVncAuth);
+        auth.authType = Swap32IfLE(rfbVncAuth);
         vncRandomBytes(cl->authChallenge);
-        memcpy(&buf[4], (char *)cl->authChallenge, CHALLENGESIZE);
+        memcpy(&(auth.buf[4]), (char *)cl->authChallenge, CHALLENGESIZE);
         len = 4 + CHALLENGESIZE;
 	cl->state = RFB_AUTHENTICATION;
 	break;
     case rfbNoAuth:
-        *(uint32_t *)buf = Swap32IfLE(rfbNoAuth);
+        auth.authType = Swap32IfLE(rfbNoAuth);
         len = 4;
         cl->state = RFB_INITIALISATION;
 	break;
@@ -182,7 +185,7 @@ rfbAuthNewClient3_3(rfbClientPtr cl)
 	return;
     }
 
-    if (WriteExact(cl, buf, len) < 0) {
+    if (WriteExact(cl, auth.buf, len) < 0) {
         rfbLogPerror("rfbAuthNewClient: write");
         rfbCloseClient(cl);
         return;
@@ -194,7 +197,7 @@ rfbAuthNewClient3_3(rfbClientPtr cl)
 void
 rfbAuthNewClient(rfbClientPtr cl)
 {
-    if (cl->minorVersion == rfbProtocolMinorVersion7)
+    if (cl->minorVersion >= rfbProtocolMinorVersion7)
 	rfbAuthNewClient3_7(cl);
     else
 	rfbAuthNewClient3_3(cl);
@@ -281,9 +284,14 @@ rfbAuthProcessSecurityTypeMessage(rfbClientPtr cl)
 	cl->state = RFB_AUTHENTICATION;
 	break;
     case rfbNoAuth:
-        cl->state = RFB_INITIALISATION;
-	if (rfbAuthClientAuthenticated(cl))
-	    rfbProcessClientInitMessage(cl);
+
+	if (cl->minorVersion >= rfbProtocolMinorVersion8)
+	    rfbAuthPasswordChecked(cl, RFB_CLIENT_ACCEPT);
+	else {
+	    cl->state = RFB_INITIALISATION;
+	    if (rfbAuthClientAuthenticated(cl))
+		rfbProcessClientInitMessage(cl);
+	}
 	break;
     default:
 	/* can't be reached */
@@ -423,6 +431,26 @@ rfbAuthPasswordChecked(rfbClientPtr            cl,
 	    return;
 	}
 
+	if (cl->minorVersion >= rfbProtocolMinorVersion8) {
+	    /* We can't really localize this string, since it has to
+	     * be iso8859-1 encoded. However, the string will only be
+	     * returned when we're using protocol version 3.8, and we
+	     * only advertise support for 3.7, so this only gets used
+	     * at all if you have a broken client.
+	     */
+	    const char errmsg[] = "Password incorrect";
+	    uint32_t len, wireLen;
+
+	    len = sizeof(errmsg) - 1;
+	    wireLen = Swap32IfLE(len);
+	    if (WriteExact(cl, (char *)&wireLen, 4) < 0 ||
+		WriteExact(cl, errmsg, len) < 0) {
+		rfbLogPerror("rfbAuthPasswordChecked: write");
+		rfbCloseClient(cl);
+		return;
+	    }
+	}
+
         rfbCloseClient(cl);
 	break;
     }
